@@ -1,3 +1,3 @@
 # Import all of the Facts you want to be made available into this file.
 
-from fact_example import Sales
+from sales.load import Sales
