@@ -1,19 +1,12 @@
 from contextlib import closing
 import logging
 
+from utils import classproperty
+
 
 log = logging.getLogger("pylytics")
 
 
-class classproperty(object):
-
-    def __init__(self, func):
-        self.func = func
-
-    def __get__(self, inst, cls):
-        return self.func(cls)
-
-
 class Warehouse(object):
     """ Global data warehouse pointer singleton. This class avoids
     having to pass a data warehouse connection into every table
@@ -53,6 +46,17 @@ class Warehouse(object):
             cursor.execute("SHOW TABLES")
             return [record[0] for record in cursor]
 
+    @classproperty
+    def trigger_names(cls):
+        """ List of trigger names which exist in the database.
+        """
+        connection = cls.get()
+        with closing(connection.cursor()) as cursor:
+            cursor.execute("""
+                SELECT trigger_name FROM information_schema.triggers
+                """)
+            return [record[0] for record in cursor]
+
     @classproperty
     def version(cls):
         """ Returns the MySQL server version number."""
